==> terraform-0.2.10.tgz: terraform-0.2.10/src/GuiDialogOAC.cc <==
/* Terraform - (C) 1997-1998 Robert Gasch (Robert_Gasch@peoplesoft.com)
 *  - www.peoplesoft.com/peoplepages/g/robert_gasch/terraform/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#include <string.h>
#include <stdlib.h>
#include "GuiDialogOAC.h"
#include "GlobalTrace.h"



/*
 *  constructor: initialize everything 
 */
GuiDialogOAC::GuiDialogOAC(char *winTitle, char *frameTitle)
	      : Gtk_Dialog (),
		d_buttonOK ("OK"),
		d_buttonApply ("Apply"),
		d_buttonCancel ("Cancel")
{
	GlobalTrace::trace (GlobalTrace::TRACE_FLOW, "+++ GuiDialogOAC\n");

	if (winTitle)
		d_winTitle = strdup (winTitle);
	else
		d_winTitle = strdup ("GuiDialogOAC Window");

	if (frameTitle)
		d_frameTitle = strdup (frameTitle);
	else
		d_frameTitle = NULL;

	d_baseFrame = NULL;
	this->set_position (GTK_WIN_POS_MOUSE);		
}


/*
 *  destructor: clean up, free allocated memory
 */
GuiDialogOAC::~GuiDialogOAC()
{
	if (d_winTitle) free (d_winTitle);	// c-type alloc from strdup
	if (d_frameTitle) free (d_frameTitle);	// c-type alloc from strdup
	if (d_baseFrame) delete d_baseFrame;

	GlobalTrace::trace (GlobalTrace::TRACE_FLOW, "--- GuiDialogOAC\n");
}


/*
 *  buildDialogWindow: call the proper functions to setup the dialog
 */
void GuiDialogOAC::buildDialogWindow ()
{
	this->set_usize (300, 120);
	this->set_title (d_winTitle);

	this->get_vbox()->set_border_width (2);

	setupVBox ();
	fillVBox ();
	fillActionArea ();

	if (d_baseFrame)
		d_baseFrame->show ();
	this->show ();
}


/*
 *  setupVBox: setup the basic frame of the vbox if necessary 
 */
void GuiDialogOAC::setupVBox ()
{
	if (d_frameTitle)
		{
		d_baseFrame = new Gtk_Frame (d_frameTitle);
		d_baseFrame->set_shadow_type (GTK_SHADOW_ETCHED_IN);
		d_baseFrame->set_border_width (6);
		this->get_vbox()->pack_start (*d_baseFrame, TRUE, TRUE, 0);
		d_baseFrame->show ();	
		}
	this->get_vbox()->show ();
}


/*
 *  fillVBox: fill the dialog's VBox 
 */
void GuiDialogOAC::fillVBox ()
{
}


/*
 *  fillActionArea: fill the dialog's action area 
 */
void GuiDialogOAC::fillActionArea ()
{
	connect_to_method (d_buttonOK.clicked, this, &buttonCallbackOK);
	this->get_action_area()->pack_start (d_buttonOK, TRUE, TRUE, 0);
	d_buttonOK.show ();

	connect_to_method (d_buttonApply.clicked, this, &buttonCallbackApply);
	this->get_action_area()->pack_start (d_buttonApply, TRUE, TRUE, 0);
	d_buttonApply.show ();

	connect_to_method (d_buttonCancel.clicked, this, &buttonCallbackCancel);
	this->get_action_area()->pack_start (d_buttonCancel, TRUE, TRUE, 0);
	d_buttonCancel.show ();
}


void GuiDialogOAC::buttonCallbackOK ()
{
	cout << "GuiDialogOAC: Default Callback OK\n";
}


void GuiDialogOAC::buttonCallbackApply ()
{
	cout << "GuiDialogOAC: Default Callback Apply\n";
}


void GuiDialogOAC::buttonCallbackCancel ()
{
	this->hide ();
}


gint GuiDialogOAC::delete_event_impl(GdkEventAny *)
{
	this->hide ();
	return (0);
}

/*
int main (int argc, char *argv[])
{
	Gtk_Main	gtkMain (&argc, &argv);
	GuiDialogOAC	*testDialog;

	testDialog = new GuiDialogOAC ("GuiDialogOAC", "Test Frame");
	testDialog->buildDialogWindow ();
	testDialog->show ();
	gtkMain.run ();
}
*/

==> terraform-0.2.11.tgz: terraform-0.2.11/src/GuiDialogOAC.cc <==
/* Terraform - (C) 1997-1998 Robert Gasch (Robert_Gasch@peoplesoft.com)
 *  - www.peoplesoft.com/peoplepages/g/robert_gasch/terraform/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#include <string.h>
#include <stdlib.h>
#include "GuiDialogOAC.h"
#include "GlobalTrace.h"



/*
 *  constructor: initialize everything 
 */
GuiDialogOAC::GuiDialogOAC(char *winTitle, char *frameTitle)
	      : Gtk_Dialog (),
		d_btnOK ("OK"),
		d_btnApply ("Apply"),
		d_btnCancel ("Cancel")
{
	GlobalTrace::trace (GlobalTrace::TRACE_FLOW, "+++ GuiDialogOAC\n");

	if (winTitle)
		d_winTitle = strdup (winTitle);
	else
		d_winTitle = strdup ("GuiDialogOAC Window");

	if (frameTitle)
		d_frameTitle = strdup (frameTitle);
	else
		d_frameTitle = NULL;

	d_baseFrame = NULL;
	this->set_position (GTK_WIN_POS_MOUSE);		
}


/*
 *  destructor: clean up, free allocated memory
 */
GuiDialogOAC::~GuiDialogOAC()
{
	if (d_winTitle) free (d_winTitle);	// c-type alloc from strdup
	if (d_frameTitle) free (d_frameTitle);	// c-type alloc from strdup
	if (d_baseFrame) delete d_baseFrame;

	GlobalTrace::trace (GlobalTrace::TRACE_FLOW, "--- GuiDialogOAC\n");
}


/*
 *  buildDialogWindow: call the proper functions to setup the dialog
 */
void GuiDialogOAC::buildDialogWindow ()
{
	this->set_usize (300, 120);
	this->set_title (d_winTitle);

	this->get_vbox()->set_border_width (2);

	setupVBox ();
	fillVBox ();
	fillActionArea ();

	if (d_baseFrame)
		d_baseFrame->show ();
	this->show ();
}


/*
 *  setupVBox: setup the basic frame of the vbox if necessary 
 */
void GuiDialogOAC::setupVBox ()
{
	if (d_frameTitle)
		{
		d_baseFrame = new Gtk_Frame (d_frameTitle);
		d_baseFrame->set_shadow_type (GTK_SHADOW_ETCHED_IN);
		d_baseFrame->set_border_width (6);
		this->get_vbox()->pack_start (*d_baseFrame, TRUE, TRUE, 0);
		d_baseFrame->show ();	
		}
	this->get_vbox()->show ();
}


/*
 *  fillVBox: fill the dialog's VBox 
 */
void GuiDialogOAC::fillVBox ()
{
}


/*
 *  fillActionArea: fill the dialog's action area 
 */
void GuiDialogOAC::fillActionArea ()
{
	connect_to_method (d_btnOK.clicked, this, &buttonCallbackOK);
	this->get_action_area()->pack_start (d_btnOK, TRUE, TRUE, 0);
	d_btnOK.show ();

	connect_to_method (d_btnApply.clicked, this, &buttonCallbackApply);
	this->get_action_area()->pack_start (d_btnApply, TRUE, TRUE, 0);
	d_btnApply.show ();

	connect_to_method (d_btnCancel.clicked, this, &buttonCallbackCancel);
	this->get_action_area()->pack_start (d_btnCancel, TRUE, TRUE, 0);
	d_btnCancel.show ();
}


void GuiDialogOAC::buttonCallbackOK ()
{
	cout << "GuiDialogOAC: Default Callback OK\n";
}


void GuiDialogOAC::buttonCallbackApply ()
{
	cout << "GuiDialogOAC: Default Callback Apply\n";
}


void GuiDialogOAC::buttonCallbackCancel ()
{
	this->hide ();
}


gint GuiDialogOAC::delete_event_impl(GdkEventAny *)
{
	this->hide ();
	return (0);
}

/*
int main (int argc, char *argv[])
{
	Gtk_Main	gtkMain (&argc, &argv);
	GuiDialogOAC	*testDialog;

	testDialog = new GuiDialogOAC ("GuiDialogOAC", "Test Frame");
	testDialog->buildDialogWindow ();
	testDialog->show ();
	gtkMain.run ();
}
*/
